﻿using Dynamicweb.Ecommerce.LiveIntegration.Configuration;
using Dynamicweb.Extensibility.Notifications;

namespace Dynamicweb.Ecommerce.LiveIntegration.NotificationSubscribers
{
    /// <summary>
    /// Synchronizes the cart with the ERP when the carty loads initially.
    /// </summary>
    /// <seealso cref="NotificationSubscriberBase" />
    [Subscribe(Ecommerce.Notifications.Ecommerce.Cart.InitiallyLoaded)]
    public class CartInitiallyLoaded : NotificationSubscriberBase
    {
        /// <summary>
        /// Handles the notification.
        /// </summary>
        /// <param name="notification">The notification.</param>
        /// <param name="args">The args.</param>
        public override void OnNotify(string notification, NotificationArgs args)
        {
            var myArgs = args as Ecommerce.Notifications.Ecommerce.Cart.LoadedArgs;

            if (myArgs?.Cart == null || myArgs.Cart.OrderLines.Count <= 0 || !EnabledAndActive())
            {
                return;
            }

            if (Global.EnableCartCommunication(myArgs.Cart.Complete))
            {
                // load cart when "Keep cart in context after checkout step" is on
                // if order is completed and exported to the ERP no need to update again
                if (myArgs.Cart.Complete && myArgs.Cart.IsExported)
                {
                    return;
                }

                OrderHandler.UpdateOrder(myArgs.Cart, SubmitType.LiveOrderOrCart);
            }
            else
            {
                CheckOrderPrices(myArgs.Cart, "Cart.InitiallyLoaded");
            }
        }
    }
}