﻿using Dynamicweb.Extensibility.Notifications;

namespace Dynamicweb.Ecommerce.LiveIntegration.NotificationSubscribers
{
    /// <summary>
    /// Updates the cart when the user logs in.
    /// </summary>
    /// <seealso cref="NotificationSubscriberBase" />
    [Subscribe(Dynamicweb.Notifications.Standard.User.OnExtranetLogin)]
    public class UserOnExtranetLogin : NotificationSubscriberBase
    {
        /// <summary>
        /// Make sure that login subscriber is executed AFTER any standard login subscribers
        /// </summary>
        public override int Rank => 1000;

        /// <summary>
        /// Handles the notification.
        /// </summary>
        /// <param name="notification">The notification.</param>
        /// <param name="args">The args.</param>
        public override void OnNotify(string notification, NotificationArgs args)
        {
            // Used to load the cart and apply the discount after the user logged-in and has not empty cart
            var myArgs = (Dynamicweb.Notifications.Standard.User.OnExtranetLoginArgs)args;
            if (EnabledAndActive() && myArgs.User != null)
            {
                Products.ProductManager.ClearUserCache();
                UrlHandler.Instance.ClearCachedUrl();

                Orders.Order order = Common.Context.Cart;
                if (order != null && order.IsCart)
                {
                    UpdateOrder(order, "OnExtranetLogin");                    
                }
            }
        }
    }
}